The source code

    /**
     * @class Ext.ensible.cal.DayBodyTemplate
     * @extends Ext.XTemplate
     * This is the template used to render the scrolling body container used in {@link Ext.ensible.cal.DayView DayView} and
     * {@link Ext.ensible.cal.WeekView WeekView}. This template is automatically bound to the underlying event store by the
     * calendar components and expects records of type {@link Ext.ensible.cal.EventRecord}.
     * Note that this template would not normally be used directly. Instead you would use the {@link Ext.ensible.cal.DayViewTemplate}
     * that internally creates an instance of this template along with a {@link Ext.ensible.cal.DayHeaderTemplate}.
     * @constructor
     * @param {Object} config The config object
     */
    Ext.ensible.cal.DayBodyTemplate = function(config){

        Ext.apply(this, config);

        Ext.ensible.cal.DayBodyTemplate.superclass.constructor.call(this,
            '',
                '',
                    '',
                        '',
                        '',
                            '',
                                '',
                                    '',
                                        '',
                                            '',
                                        '',
                                    '',
                                '',
                            '',
                        '',
                    '',
                    '',
                        '',
                            '',
                                '',
                                    '{.}',
                                '',
                            '',
                        '',
                        '',
                            '',
                                '',
                                    '',
                                '',
                            '',
                        '',
                    '',
                '',
            ''
        );
    };

    Ext.extend(Ext.ensible.cal.DayBodyTemplate, Ext.XTemplate, {
        // private
        applyTemplate : function(o){
            this.today = new Date().clearTime();
            this.dayCount = this.dayCount || 1;

            var i = 0, days = [],
                dt = o.viewStart.clone();

            for(; i